#
# spec file for package python-unearth
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-unearth
Version:        0.17.2
Release:        1.3
Summary:        A utility to fetch and download python packages
License:        MIT
URL:            https://unearth.readthedocs.io/
Source:         https://files.pythonhosted.org/packages/source/u/unearth/unearth-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module packaging >= 20}
BuildRequires:  %{python_module pdm-backend}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-httpx
Requires:       python-packaging >= 20
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test
BuildRequires:  %{python_module Flask >= 2.1.2}
BuildRequires:  %{python_module httpx}
BuildRequires:  %{python_module pytest-httpserver >= 1.0.4}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests-wsgi-adapter >= 0.4.1}
BuildRequires:  %{python_module trustme >= 0.9.0}
# /SECTION
%python_subpackages

%description
This project exists as the last piece to complete the puzzle of a package manager. The other pieces are:

- python-resolvelib - Resolves concrete dependencies from a set of (abstract) requirements.
- python-unearth - Finds and downloads the best match(es) for a given requirement.
- python-build - Builds wheels from the source code.
- python-installer - Installs packages from wheels.

They provide all the low-level functionalities that are needed to resolve and install packages.

%prep
%setup -q -n unearth-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/unearth
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative unearth

%postun
%python_uninstall_alternative unearth

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/unearth
%{python_sitelib}/unearth
%{python_sitelib}/unearth-%{version}.dist-info

%changelog
* Fri Sep 27 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.17.2:
  * Really drop python<=3.7 support
  * Don't show warning message when no netrc exists
  * Show warning message when failing to parse netrc file
  * Report download status when checking out vcs repo
  * Allow using local file:// locations with find_links and index_urls
  * New method check_wheel_tags for override
* Tue Jul  2 2024 Daniel Garcia <daniel.garcia@suse.com>
- Update to 0.15.5:
  * Add keyring cli get creds mode
  * Fix release note autogenerator
- 0.15.4
  * Skip netrc when parse failed
  * Update dependencies
  * Switch to trusted publisher
  * Test on 3.13
- 0.15.3
  * Allow passing headers to package finder
  * ci: Matrix for old python versions on macos
- 0.15.2
  * Incorrect username when using system keyring CLI
- 0.15.1
  * Close local files after read
- 0.15.0
  * Support exclude_newer_than evaluation
  * Support httpx.Client
* Sun Jan 21 2024 Dirk Müller <dmueller@suse.com>
- update to 0.14.0:
  * Extract the wheel tag validation method
  * Remove the hashes argument from PackageFinder.build_evaluator
    that is deprecated before
  * Drop support for Python 3.7
  * Add PyPI as the default index in PackageFinder
  * Add a default timeout to the session
  * Support fetching from Git refs
  * Update hg.py to use the commit hash instead of the local
    identity
* Mon Dec  4 2023 Dirk Müller <dmueller@suse.com>
- update to 0.12.1:
  * Match index url with the same netloc
* Mon Oct 23 2023 Dirk Müller <dmueller@suse.com>
- update to 0.12.0 (bsc#1216480, CVE-2023-45805):
  * Add callback to report download status
  * Respect :all: in prefer_binary config
  * security: Validate the package name extracted from the part
    before the last hyphen
  * Also fallback on "token" username for KeyringCliProvider
  * Revert the handling of 403 and 404
  * Handle 403 same as 401, and look for credentials on 404 error
  * Close response files correctly
  * Change FormatControl to respect the priority of only_binary
    over no_binary
  * Include useful message if VCS command not found
  * Postpone the validation of hashes
  * Migrate from deprecated pdm.pep517 to pdm.backend
  * Tolerate invalid python requires
  * Fix the dist info link evaluation
  * PEP 714: rename the dist-info-metadata field to core-metadata
* Thu Jun 15 2023 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.9.1
  * cli: Exposing requires-python, platform and abi interface for cli tools.  -
    by @frostming in #52 (b9935)
  * Evaluation issue when the requirement has no version specifier Close #50  -
    by @frostming in #50 (0a813)
  * Typo on json response field  -  by @frostming (3e767)
  * Update pdm.lock  -  by @github-actions[bot] and frostming in #44 (e4572)
  * Update pdm.lock  -  by @github-actions[bot] in #45 (a98b9)
  * Update pdm.lock  -  by @github-actions[bot] in #47 (e0ea7)
  * Update pdm.lock  -  by @github-actions[bot] and frostming in #49 (fc994)
  * Allow to order the index urls and find links together for PackageFinder  -
    by @frostming in #43 (dbe85)
  * Allow to set prefer_binary for individual packages.
- Use sle15_python_module_pythons
* Thu Dec 15 2022 Torsten Gruner <simmphonie@opensuse.org>
- Update to version 0.7.0
  * Features
    + Suppress warnings for insecure requests  -  by @frostming (419df)
    + Support PEP 691: JSON simple API and PEP 658: static metadata in API  -  by @frostming in #28 (6dadc)
  * Bug Fixes
    + Fix the logger name to be zipapp friendly  -  by @frostming in #29 (5d930)
- Version 0.6.3
  * Bug Fixes
    + Skip invalid versions rejected by packaging 22.0  -  by @pdm-project in #26 (8fc2a)
  * Documentation
    + Update the version in docs  -  by @pdm-project (f2a02)
* Tue Dec  6 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.6.2
  * Features
  Log the file size when downloading  -  by @frostming in #22 (9514a)
  Use token as the username if not specified Close #18  -  by @frostming in #18 (6d2a6)
  Add more logs about the caches  -  by @frostming (e0000)
  * Bug Fixes
  Cache the index fetch result in memory  -  by @frostming (eacc0)
  * Chores
  Add python 3.11 to the test matrix  -  by @frostming (25338)
* Mon Aug 15 2022 Ben Greiner <code@bnavigator.de>
- Initial specfile for v0.6.1
- Required by python-pdm v2
